@@ -32,7 +32,7 @@ from pyworkflow import Config
 from .constants import *
 
 
-__version__ = "3.0.5"
+__version__ = "3.2.0"
 _logo = "icon.png"
 _references = ['Zhang2021']
 
@@ -41,18 +41,6 @@ class Plugin(pwem.Plugin):
     _supportedVersions = VERSIONS
     _url = "https://github.com/scipion-em/scipion-em-prody"
 
-    @classmethod
-    def _defineVariables(cls):
-        cls._defineVar(PRODY_ENV_ACTIVATION, DEFAULT_ACTIVATION_CMD)
-
-    @classmethod
-    def getProDyEnvActivation(cls):
-        """ Remove the scipion home and activate the conda environment. """
-        activation = cls.getVar(PRODY_ENV_ACTIVATION)
-        scipionHome = Config.SCIPION_HOME + os.path.sep
-
-        return activation.replace(scipionHome, "", 1)
-
     @classmethod
     def getEnviron(cls):
         """ Setup the environment variables needed to launch ProDy. """
@@ -82,29 +70,23 @@ class Plugin(pwem.Plugin):
     @classmethod
     def addProDyPackage(cls, env, version, default=False):
         PRODY_INSTALLED = 'prody_%s_installed' % version
-        # ENV_NAME = 'scipion3'
-        # # try to get CONDA activation command
-        # installCmd = [cls.getCondaActivationCmd()]
         installCmd = []
-        #
-        # # Activate the new environment
-        # installCmd.append('conda activate %s;' % ENV_NAME)
 
         if version == DEVEL:
             # Use latest scipion branch of prody on my github
             installCmd.append('cd .. &&')
             clonePath = os.path.join(pwem.Config.EM_ROOT, "ProDy")
             if not os.path.exists(clonePath):
-                installCmd.append('git clone -b scipion https://github.com/jamesmkrieger/ProDy.git  ProDy &&')
-            # Install downloaded code
-            installCmd.append('cd ProDy && pip install -U -e . && python setup.py build_ext --inplace --force &&')
+                installCmd.append('git clone -b scipion https://github.com/jamesmkrieger/ProDy.git ProDy &&')
+            installCmd.append('cd ProDy &&')
+
+        # Install downloaded code
+        installCmd.append('pip install -U -e . && python setup.py build_ext --inplace --force &&')
+
+        if version == DEVEL:
             installCmd.append('cd .. && cd prody-github &&')
-        else:
-            installCmd.append('pip install -U ProDy==%s &&' % version)
 
-        # configure ProDy to automatically handle secondary structure information
         installCmd.append('python -c "import os; os.environ.setdefault(\'HOME\', \'{0}\')" &&'.format(Config.SCIPION_HOME + os.path.sep))
-        installCmd.append('python -c "import prody; prody.confProDy(auto_secondary=True)" &&')
 
         # Flag installation finished
         installCmd.append('touch %s' % PRODY_INSTALLED)
@@ -125,7 +107,8 @@ class Plugin(pwem.Plugin):
                             vars=installEnvVars)
         else:
             env.addPackage('prody', version=version,
-                           tar='void.tgz',
+                           url='https://github.com/prody/ProDy/archive/refs/tags/v{0}.tar.gz'.format(version),
+                           buildDir='ProDy-{0}'.format(version),
                            commands=prody_commands,
                            neededProgs=cls.getDependencies(),
                            default=default,
@@ -134,18 +117,8 @@ class Plugin(pwem.Plugin):
     @classmethod
     def getProgram(cls, program):
         """ Create ProDy command line. """
-        fullProgram = '%s %s && prody %s' % (
-            cls.getCondaActivationCmd(), cls.getProDyEnvActivation(),
+        fullProgram = '%s && prody %s' % (
+            cls.getCondaActivationCmd(),
             program)
 
         return fullProgram
-
-    @classmethod
-    def getActiveVersion(cls, *args):
-        """ Return the env name that is currently active. """
-        envVar = cls.getVar(PRODY_ENV_ACTIVATION)
-        return envVar.split()[-1]
-
-    @classmethod
-    def IS_V211(cls):
-        return cls.getActiveVersion().startswith(getProDyEnvName('2.1.1'))
