@@ -29,11 +29,6 @@ def getProDyEnvName(version):
     return "prody-%s" % version
 
 DEVEL = 'github'
-V211 = '2.1.1'
-VERSIONS = [DEVEL, V211]
-PRODY_DEFAULT_VER_NUM = V211
-
-DEFAULT_ENV_NAME = getProDyEnvName(PRODY_DEFAULT_VER_NUM)
-DEFAULT_ACTIVATION_CMD = 'conda activate ' + DEFAULT_ENV_NAME
-PRODY_ENV_ACTIVATION = DEFAULT_ACTIVATION_CMD
-
+V220 = '2.2.0'
+VERSIONS = [DEVEL, V220]
+PRODY_DEFAULT_VER_NUM = V220
