@@ -4,10 +4,17 @@
 # Find documentation here: https://scipion-em.github.io/docs/docs/developer/creating-a-protocol
 # **************************************************************************
 from .protocol_anm import ProDyANM
-# from .protocol_rtb import ProDyRTB
+from .protocol_rtb import ProDyRTB
+from .protocol_gnm import ProDyGNM
+from .protocol_domdec import ProDyDomainDecomp 
 
 from .protocol_atoms import ProDySelect, ProDyAlign
 from .protocol_compare import ProDyCompare
 from .protocol_edit import ProDyEdit
 from .protocol_defvec import ProDyDefvec
-from .protocol_import import ProDyImportModes
\ No newline at end of file
+from .protocol_import import ProDyImportModes
+
+from .protocol_ensemble import ProDyBuildPDBEnsemble
+from .protocol_import import ProDyImportEnsemble
+from .protocol_pca import ProDyPCA
+from .protocol_project import ProDyProject
