@@ -97,6 +97,11 @@ class ProDyCompare(EMProtocol):
                       label='Match modes',
                       help='Elect whether to match modes.')     
 
+        form.addParam('norm', BooleanParam, default=True, 
+                      condition='metric==%d' % NMA_METRIC_OVERLAP,
+                      label='Normalise overlaps',
+                      help='Elect whether to normalise vectors for overlaps or calculate raw dot products.')
+
     # --------------------------- STEPS functions ------------------------------
     def _insertAllSteps(self):
         # Insert processing steps
@@ -104,24 +109,38 @@ class ProDyCompare(EMProtocol):
         self._insertFunctionStep('createOutputStep')
 
     def compareModesStep(self):
+        # configure ProDy to automatically handle secondary structure information and verbosity
+        old_secondary = prody.confProDy("auto_secondary")
+        old_verbosity = prody.confProDy("verbosity")
+        from pyworkflow import Config
+        prodyVerbosity =  'none' if not Config.debugOn() else 'debug'
+        prody.confProDy(auto_secondary=True, verbosity='{0}'.format(prodyVerbosity))
+
+        modes1_path = os.path.dirname(os.path.dirname(
+            self.modes1.get()._getMapper().selectFirst().getModeFile()))
 
-        modes1_path = os.path.dirname(os.path.dirname(self.modes1.get()[1].getModeFile()))
         pdb1 = glob(modes1_path+"/*atoms.pdb")
         if len(pdb1) == 0:
             pdb1 = None
-        modes1 = prody.parseScipionModes(modes1_path, pdb=pdb1)
 
-        modes2_path = os.path.dirname(os.path.dirname(self.modes2.get()[1].getModeFile()))
+        modes1 = prody.parseScipionModes(self.modes1.get().getFileName(), pdb=pdb1)
+
+        modes2_path = os.path.dirname(os.path.dirname(
+            self.modes2.get()._getMapper().selectFirst().getModeFile()))
+            
         pdb2 = glob(modes1_path+"/*atoms.pdb")
         if len(pdb2) == 0:
             pdb2 = None
-        modes2 = prody.parseScipionModes(modes2_path, pdb=pdb2)
+
+        modes2 = prody.parseScipionModes(self.modes2.get().getFileName(), pdb=pdb2)
 
         n_modes = np.max([modes1.numModes(), modes2.numModes()])
         min_n_modes = np.min([modes1.numModes(), modes2.numModes()])
         if modes1.numModes() != modes2.numModes() and min_n_modes != 1:
-            raise ValueError('The two sets should have the same number of nodes '
-                           'unless one of them has exactly 1 mode in it.')
+            raise ValueError('The two sets should have the same number of modes '
+                             'unless one of them has exactly 1 mode in it.\n'
+                             'modes1 has {0} and modes2 has {1}'.format(modes1.numModes(),
+                                                                        modes2.numModes()))
 
         if min_n_modes != 1:
             mode_ens = prody.ModeEnsemble()
@@ -136,14 +155,24 @@ class ProDyCompare(EMProtocol):
                                  np.array(match_inds, dtype=int)[1]+1,
                                  format='%3d')
 
-                atoms = prody.parsePDB(self.modes1.get().getPdb().getFileName())
+                pdb = self.modes1.get().getPdb()
+                if pdb is not None:
+                    atoms = prody.parsePDB(pdb.getFileName())
+                else:
+                    atoms = prody.parsePDB(pdb1)
+
                 prody.writeNMD(self._getExtraPath('matched_modes.nmd'), mode_ens[1], atoms)
                 prody.writeScipionModes(self._getPath(), mode_ens[1], write_star=True)
         else:
             mode_ens = [modes1, modes2]
         
         if self.metric == NMA_METRIC_OVERLAP:
-            self.matrix = prody.calcOverlap(mode_ens[0], mode_ens[1], diag=self.diag)
+            if self.norm:
+                self.matrix = prody.calcOverlap(mode_ens[0], mode_ens[1], diag=self.diag)
+            else:
+                # Calculate direct dot product without vector normalisation found in calcOverlap
+                self.matrix = modes1.getEigvecs().T @ modes2.getEigvecs()
+
             if self.matrix.ndim == 1:
                 self.matrix.reshape(-1, 1)
 
@@ -155,7 +184,13 @@ class ProDyCompare(EMProtocol):
                 else:
                     self.matrix[i-6, 0] = prody.calcRWSIP(mode_ens[0, 6:i+1], mode_ens[1, 6:i+1])
 
-        prody.writeArray(self._getExtraPath('matrix.txt'), self.matrix)
+        pre_dec_len = max([len(str(int(np.max(self.matrix)))), len(str(int(np.min(self.matrix))))])
+        format_str = '%' + str(pre_dec_len + 4) + '.2f'
+
+        prody.writeArray(self._getExtraPath('matrix.txt'), self.matrix, format=format_str)
+
+        # configure ProDy to restore secondary structure information and verbosity
+        prody.confProDy(auto_secondary=old_secondary, verbosity='{0}'.format(old_verbosity))
 
     def createOutputStep(self):
         outputMatrix = EMFile(filename=self._getExtraPath('matrix.txt'))
