@@ -105,6 +105,13 @@ class ProDyDefvec(EMProtocol):
         self._insertFunctionStep('createOutputStep')
 
     def defvecStep(self, mobFn, tarFn):
+        # configure ProDy to automatically handle secondary structure information and verbosity
+        self.old_secondary = prody.confProDy("auto_secondary")
+        self.old_verbosity = prody.confProDy("verbosity")
+        from pyworkflow import Config
+        prodyVerbosity =  'none' if not Config.debugOn() else 'debug'
+        prody.confProDy(auto_secondary=True, verbosity='{0}'.format(prodyVerbosity))
+
         self.mob = prody.parsePDB(mobFn, alt='all')
         self.tar = prody.parsePDB(tarFn, alt='all')
 
@@ -173,6 +180,10 @@ class ProDyDefvec(EMProtocol):
             md.setValue(MDL_NMA_MODEFILE, fnVec, objId)
         md.write(self._getExtraPath('maxAtomShifts.xmd'))
 
+        # configure ProDy to restore secondary structure information and verbosity
+        prody.confProDy(auto_secondary=self.old_secondary, 
+                        verbosity='{0}'.format(self.old_verbosity))
+
     def createOutputStep(self):
         fnSqlite = self._getPath('modes.sqlite')
         nmSet = SetOfNormalModes(filename=fnSqlite)
